#!/bin/zsh

# basic functions
die() {
  echo "$*" >/dev/stderr
  exit 1
}
debug() { #change to false to disable debugging
  #true && echo "$*" >>debug
  true && [ -n "$*" ] && echo -E "$*" >>/dev/stderr
  true && [ -z "$*" ] && tee /dev/stderr
}

# this program is supposed to be symlinked into a http root directory
# we will use the http root as object storage (data directory) and call sub
# programs from the directory in which the real executable resides
# therefore we need to identify the code and data directories _EXEC and _DATA
call="$0"
real="$(readlink -f $call)"
_EXEC="$(dirname "$real")"  #execution directory
_DATA="$(dirname "$call")"  #storage directory

[ -w "$_DATA" ] && [ -d "$_DATA" ] || die "storage directory must be writable"

# create directories for object storage
for each in "$_DATA"/{vcard,mappings,courses,cache,temp}; do
  [ ! -e "$each" ] && mkdir "$each"
  [ -w "$each" ] && [ -d "$each" ] || die "storage $each must be a writable directory"
done

# create htaccess file
[ -f .htaccess ] || cat >.htaccess <<EOF
Options		+ExecCGI
AddHandler	cgi-script .cgi
DirectoryIndex	index.cgi
EOF
[ -f .htaccess ] || die "no htaccess file present and unable to create one"

. "$_EXEC/cgi.sh"

cgi_get

. "$_EXEC/constants.sh"

if [ -n "$_GET[\"action\"]" ]; then
  . "$_EXEC/action.sh"
elif [ -n "$_GET[\"export\"]" ]; then
  . "$_EXEC/export.sh"
else
  . "$_EXEC/page.sh"
fi
